import java.util.*;


/**
 * 
 * A PredictionObject stores information about the predictions to be made and 
 * then accepts and stores the predictions. 
 *
 */
public class PredictionObject {
	final static int numComputers = 16; 
	double[] medianPrices = new double[numComputers];
	boolean futureComputerPriceNeeded;
	boolean computerPriceNeeded;
	Message[] futureComponentRFQList;
	Hashtable computerRFQPrices = new Hashtable();
	Hashtable componentRFQPrices = new Hashtable();
	Hashtable futureComponentRFQPrices = new Hashtable();
	
	
	/**
	 * Set by the parser.
	 */
	public void setFutureComputerPriceNeeded(boolean b){
		futureComputerPriceNeeded = b;
	}
	
	/**
	 * Indicates whether prediction of future computer prices is required today
	 */
	public boolean getFutureComputerPriceNeeded(){
		return futureComputerPriceNeeded;
	}
	
	/**
	 * Set by the parser.
	 */
	public void setComputerPriceNeeded(boolean b){
		computerPriceNeeded = b;
	}

	/**
	 * Indicates whether prediction of current computer prices is required today
	 */
	public boolean getComputerPriceNeeded(){
		return computerPriceNeeded;
	}
	
	/**
	 * specify the predicted future median computer price
	 * @param productID  the ID of the computer
	 * @param price  the unit price
	 */
	public void setFutureMedianComputerPrice(int productID, double price){
		medianPrices[productID - 1] = price;
	}
	
	/**
	 * Allows the parser to read the prediction.
	 */
	public double getFutureMedianComputerPrice(int productID){
		return medianPrices[productID - 1];
	}
	
	/**
	 * specify the predicted price of the resulting computer order (if any)
	 * @param productID  the ID of the RFQ
	 * @param price  the unit price
	 */
	public void setComputerRFQPrice(int rfqID, double price){
		computerRFQPrices.put(new Integer(rfqID), new Double(price));
	}

	/**
	 * Allows the parser to read the prediction.
	 */
	public double getComputerRFQPrice(int rfqID){
		Double d = (Double) computerRFQPrices.get(new Integer(rfqID));
		if (d == null)
			return Double.NaN;
		else
			return d.doubleValue();
	}

	/**
	 * Set by the parser.
	 */
	public void setFutureComponentRFQList(Message[] list){
		futureComponentRFQList = list;
	}
	
	/**
	 * returns the number of future RFQs for which predictions are required
	 */
	public int getFutureComponentRFQCount(){
		return futureComponentRFQList.length;
	}
	
	/**
	 * Returns an RFQBundle containing a future component RFQ.  
	 * The RFQBundle is stored in a Message from the manufacturer to the supplier.
	 */
	public Message getFutureComponentRFQ(int index){
		if (index >= 0 && index < futureComponentRFQList.length)
			return futureComponentRFQList[index];
		else
			return null;
	}
	
	/**
	 * specify the predicted price that will be offered for the future component RFQ
	 * @param productID  the ID of the RFQ
	 * @param price  the unit price
	 */
	public void setFutureComponentRFQPrice(int rfqID, double price){
		futureComponentRFQPrices.put(new Integer(rfqID), new Double(price));
	}
	
	/**
	 * Allows the parser to read the prediction.
	 */
	public double getFutureComponentRFQPrice(int rfqID){
		Double d = (Double) futureComponentRFQPrices.get(new Integer(rfqID));
		if (d == null)
			return Double.NaN;
		else
			return d.doubleValue();
	}
	
	/**
	 * specify the predicted price that will be offered for the component RFQ
	 * @param productID  the ID of the RFQ
	 * @param price  the unit price
	 */
	public void setComponentRFQPrice(int rfqID, double price){
		componentRFQPrices.put(new Integer(rfqID), new Double(price));
	}
	
	/**
	 * Allows the parser to read the prediction.
	 */
	public double getComponentRFQPrice(int rfqID){
		Double d = (Double) componentRFQPrices.get(new Integer(rfqID));
		if (d == null)
			return Double.NaN;
		else
			return d.doubleValue();
	}
	
	
	
}
